@@ -24,9 +24,10 @@ from graphene import (
     UUID,
 )
 from graphene.types.json import JSONString
-from graphene.utils.str_converters import to_camel_case, to_const
+from graphene.utils.str_converters import to_camel_case
 from graphene_django.compat import ArrayField, HStoreField, RangeField, JSONField
-from graphene_django.utils import import_single_dispatch
+from functools import singledispatch
+from graphene_django.utils.str_converters import to_const
 
 from .base_types import (
     GenericForeignKeyType,
@@ -39,9 +40,6 @@ from .base_types import (
 from .fields import DjangoFilterListField, DjangoListField
 from .utils import is_required, get_model_fields, get_related_model
 
-singledispatch = import_single_dispatch()
-
-
 NAME_PATTERN = r"^[_a-zA-Z][_a-zA-Z0-9]*$"
 COMPILED_NAME_PATTERN = re.compile(NAME_PATTERN)
 
@@ -147,7 +145,7 @@ def construct_fields(
             if input_flag == "create" and name == "id":
                 continue
             is_included = include_fields and name in include_fields
-            nested_field = True if name in nested_fields else False
+            nested_field = name in nested_fields
             is_not_in_only = only_fields and name not in only_fields
             # is_already_created = name in options.fields
             is_excluded = (
