@@ -1,15 +1,23 @@
 # -*- coding: utf-8 -*-
 from django_filters.filterset import BaseFilterSet, FilterSet
 from django_filters.filterset import FILTER_FOR_DBFIELD_DEFAULTS
+from graphene_django.filter.utils import replace_csv_filters
 
 
 def get_filterset_class(filterset_class, **meta):
-    """Get the class to be used as the FilterSet"""
+    """
+    Get the class to be used as the FilterSet.
+    """
     if filterset_class:
-        # If were given a FilterSet class, then set it up and
-        # return it
-        return setup_filterset(filterset_class)
-    return custom_filterset_factory(**meta)
+        # If were given a FilterSet class, then set it up.
+        graphene_filterset_class = setup_filterset(filterset_class)
+    else:
+        # Otherwise create one.
+        graphene_filterset_class = custom_filterset_factory(**meta)
+
+    replace_csv_filters(graphene_filterset_class)
+
+    return graphene_filterset_class
 
 
 class GrapheneFilterSetMixin(BaseFilterSet):
