@@ -130,8 +130,11 @@ class DjangoObjectType(ObjectType):
             return True
         if not is_valid_django_model(type(root)):
             raise Exception(('Received incompatible instance "{}".').format(root))
-        model = root._meta.model
-        return model == cls._meta.model
+        return isinstance(root, cls._meta.model)
+
+    @classmethod
+    def get_queryset(cls, queryset, info):
+        return queryset
 
     @classmethod
     def get_node(cls, info, id):
@@ -609,7 +612,7 @@ class DjangoSerializerType(ObjectType):
     def list(cls, manager, filterset_class, filtering_args, root, info, **kwargs):
 
         qs = queryset_factory(
-            cls._meta.queryset or manager, info.field_asts, info.fragments, **kwargs
+            cls._meta.queryset or manager, info.field_nodes, info.fragments, **kwargs
         )
 
         filter_kwargs = {k: v for k, v in kwargs.items() if k in filtering_args}
